@@ -16,14 +16,14 @@ def _get_kwargs(
     *,
     client: AuthenticatedClient,
     json_body: EventTypeIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/event-type/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body.to_dict()
@@ -64,7 +64,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EventTypeIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Create Event Type
 
@@ -75,7 +75,7 @@ def sync_detailed(
     This operation does not preserve the description and schemas.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeIn):
 
     Returns:
@@ -111,7 +111,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: EventTypeIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Create Event Type
 
@@ -122,7 +122,7 @@ def sync(
     This operation does not preserve the description and schemas.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeIn):
 
     Returns:
@@ -140,7 +140,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EventTypeIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Create Event Type
 
@@ -151,7 +151,7 @@ async def asyncio_detailed(
     This operation does not preserve the description and schemas.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeIn):
 
     Returns:
@@ -185,7 +185,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: EventTypeIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Create Event Type
 
@@ -196,7 +196,7 @@ async def asyncio(
     This operation does not preserve the description and schemas.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EventTypeIn):
 
     Returns:
