@@ -15,14 +15,14 @@ def _get_kwargs(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/event-type/{event_type_name}/".format(client.base_url, event_type_name=event_type_name)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     return {
@@ -60,7 +60,7 @@ def sync_detailed(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Get Event Type
 
@@ -68,7 +68,7 @@ def sync_detailed(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EventTypeOut
@@ -103,7 +103,7 @@ def sync(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Get Event Type
 
@@ -111,7 +111,7 @@ def sync(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EventTypeOut
@@ -128,7 +128,7 @@ async def asyncio_detailed(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Get Event Type
 
@@ -136,7 +136,7 @@ async def asyncio_detailed(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EventTypeOut
@@ -169,7 +169,7 @@ async def asyncio(
     event_type_name: str,
     *,
     client: AuthenticatedClient,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> EventTypeOut:
     """Get Event Type
 
@@ -177,7 +177,7 @@ async def asyncio(
 
     Args:
         event_type_name (str):  Example: user.signup.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         EventTypeOut
