@@ -18,14 +18,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     json_body: MessageIn,
     with_content: Union[Unset, None, bool] = True,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/msg/".format(client.base_url, app_id=app_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -76,7 +76,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     json_body: MessageIn,
     with_content: Union[Unset, None, bool] = True,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Create Message
 
@@ -98,7 +98,7 @@ def sync_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         with_content (Union[Unset, None, bool]):  Default: True.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (MessageIn):
 
     Returns:
@@ -138,7 +138,7 @@ def sync(
     client: AuthenticatedClient,
     json_body: MessageIn,
     with_content: Union[Unset, None, bool] = True,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Create Message
 
@@ -160,7 +160,7 @@ def sync(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         with_content (Union[Unset, None, bool]):  Default: True.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (MessageIn):
 
     Returns:
@@ -182,7 +182,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     json_body: MessageIn,
     with_content: Union[Unset, None, bool] = True,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Create Message
 
@@ -204,7 +204,7 @@ async def asyncio_detailed(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         with_content (Union[Unset, None, bool]):  Default: True.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (MessageIn):
 
     Returns:
@@ -242,7 +242,7 @@ async def asyncio(
     client: AuthenticatedClient,
     json_body: MessageIn,
     with_content: Union[Unset, None, bool] = True,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> MessageOut:
     """Create Message
 
@@ -264,7 +264,7 @@ async def asyncio(
     Args:
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         with_content (Union[Unset, None, bool]):  Default: True.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (MessageIn):
 
     Returns:
