@@ -15,9 +15,9 @@ class EnvironmentSettingsOut:
     Attributes:
         color_palette_dark (Union[Unset, CustomColorPalette]):
         color_palette_light (Union[Unset, CustomColorPalette]):
-        custom_color (Union[Unset, str]):
-        custom_font_family (Union[Unset, str]):  Example: Open Sans.
-        custom_logo_url (Union[Unset, str]):
+        custom_color (Union[Unset, None, str]):
+        custom_font_family (Union[Unset, None, str]):  Example: Open Sans.
+        custom_logo_url (Union[Unset, None, str]):
         custom_theme_override (Union[Unset, CustomThemeOverride]):
         enable_channels (Union[Unset, bool]):
         enable_integration_management (Union[Unset, bool]):
@@ -25,9 +25,9 @@ class EnvironmentSettingsOut:
 
     color_palette_dark: Union[Unset, CustomColorPalette] = UNSET
     color_palette_light: Union[Unset, CustomColorPalette] = UNSET
-    custom_color: Union[Unset, str] = UNSET
-    custom_font_family: Union[Unset, str] = UNSET
-    custom_logo_url: Union[Unset, str] = UNSET
+    custom_color: Union[Unset, None, str] = UNSET
+    custom_font_family: Union[Unset, None, str] = UNSET
+    custom_logo_url: Union[Unset, None, str] = UNSET
     custom_theme_override: Union[Unset, CustomThemeOverride] = UNSET
     enable_channels: Union[Unset, bool] = False
     enable_integration_management: Union[Unset, bool] = False
