@@ -15,32 +15,32 @@ class SettingsOut:
     Attributes:
         color_palette_dark (Union[Unset, CustomColorPalette]):
         color_palette_light (Union[Unset, CustomColorPalette]):
-        custom_base_font_size (Union[Unset, int]):
-        custom_color (Union[Unset, str]):
-        custom_font_family (Union[Unset, str]):  Example: Open Sans.
-        custom_logo_url (Union[Unset, str]):
+        custom_base_font_size (Union[Unset, None, int]):
+        custom_color (Union[Unset, None, str]):
+        custom_font_family (Union[Unset, None, str]):  Example: Open Sans.
+        custom_logo_url (Union[Unset, None, str]):
         custom_theme_override (Union[Unset, CustomThemeOverride]):
         disable_endpoint_on_failure (Union[Unset, bool]):  Default: True.
-        display_name (Union[Unset, str]):
+        display_name (Union[Unset, None, str]):
         enable_channels (Union[Unset, bool]):
         enable_integration_management (Union[Unset, bool]):
         enforce_https (Union[Unset, bool]):  Default: True.
-        event_catalog_published (Union[Unset, bool]):
+        event_catalog_published (Union[Unset, None, bool]):
     """
 
     color_palette_dark: Union[Unset, CustomColorPalette] = UNSET
     color_palette_light: Union[Unset, CustomColorPalette] = UNSET
-    custom_base_font_size: Union[Unset, int] = UNSET
-    custom_color: Union[Unset, str] = UNSET
-    custom_font_family: Union[Unset, str] = UNSET
-    custom_logo_url: Union[Unset, str] = UNSET
+    custom_base_font_size: Union[Unset, None, int] = UNSET
+    custom_color: Union[Unset, None, str] = UNSET
+    custom_font_family: Union[Unset, None, str] = UNSET
+    custom_logo_url: Union[Unset, None, str] = UNSET
     custom_theme_override: Union[Unset, CustomThemeOverride] = UNSET
     disable_endpoint_on_failure: Union[Unset, bool] = True
-    display_name: Union[Unset, str] = UNSET
+    display_name: Union[Unset, None, str] = UNSET
     enable_channels: Union[Unset, bool] = False
     enable_integration_management: Union[Unset, bool] = False
     enforce_https: Union[Unset, bool] = True
-    event_catalog_published: Union[Unset, bool] = False
+    event_catalog_published: Union[Unset, None, bool] = False
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
